cpp-runner
==========

A simple cpp file runner with no external dependencies.

To install, simply type:

    pip install cpp-runner

To run a cpp file, type this:

    crun <filename> [-q]

The filename argument is mandatory. The -q argument switches off console output.